shithub: pokered

Download patch

ref: f8a9c37a0019eb085c22c6e3ae53b16ff0cd4f6a
parent: 891627d4ba193dd839e03e9e30f1e492e57eac9f
author: dannye <corrnondacqb@yahoo.com>
date: Wed Aug 5 12:20:29 EDT 2015

Use more lb

and other clean up

--- a/engine/HoF_room_pc.asm
+++ b/engine/HoF_room_pc.asm
@@ -164,7 +164,7 @@
 FillMiddleOfScreenWithWhite: ; 74183 (1d:4183)
 	coord hl, 0, 4
 	ld bc, SCREEN_WIDTH * 10
-	ld a, $7f ; blank white tile
+	ld a, " "
 	jp FillMemory
 
 Credits: ; 7418e (1d:418e)
@@ -246,7 +246,7 @@
 	pop de
 	ld de, TheEndGfx
 	ld hl, vChars2 + $600
-	ld bc, (BANK(TheEndGfx) << 8) + $0a
+	lb bc, BANK(TheEndGfx), $0a
 	call CopyVideoData
 	coord hl, 4, 8
 	ld de, TheEndTextString
--- a/engine/battle/battle_transitions.asm
+++ b/engine/battle/battle_transitions.asm
@@ -184,7 +184,7 @@
 LoadBattleTransitionTile: ; 70a4d (1c:4a4d)
 	ld hl, vChars1 + $7f0
 	ld de, BattleTransitionTile
-	ld bc, (BANK(BattleTransitionTile) << 8) + $01
+	lb bc, BANK(BattleTransitionTile), $01
 	jp CopyVideoData
 
 BattleTransitionTile: ; 70a59 (1c:4a59)
--- a/engine/battle/core.asm
+++ b/engine/battle/core.asm
@@ -102,7 +102,7 @@
 	ld [wTextBoxID], a
 	call DisplayTextBoxID
 	coord hl, 1, 5
-	ld bc, $307
+	lb bc, 3, 7
 	call ClearScreenArea
 	call DisableLCD
 	call LoadFontTilePatterns
@@ -110,7 +110,7 @@
 	ld hl, vBGMap0
 	ld bc, $400
 .clearBackgroundLoop
-	ld a, $7f
+	ld a, " "
 	ld [hli], a
 	dec bc
 	ld a, b
@@ -717,8 +717,8 @@
 	ld [wHPBarMaxHP+1], a
 	ld a, [hl]
 	ld [wHPBarMaxHP], a
-	ld de, $fff2
-	add hl, de           ; skip back fomr max hp to current hp
+	ld de, wBattleMonHP - wBattleMonMaxHP
+	add hl, de           ; skip back from max hp to current hp
 	ld a, [hl]
 	ld [wHPBarOldHP], a ; add bc to current HP
 	add c
@@ -852,7 +852,7 @@
 	coord de, 12, 6
 	call SlideDownFaintedMonPic
 	coord hl, 0, 0
-	ld bc, $40b
+	lb bc, 4, 11
 	call ClearScreenArea
 	ld a, [W_ISINBATTLE]
 	dec a
@@ -1100,7 +1100,7 @@
 	ld [wBattleMonStatus], a
 	call ReadPlayerMonCurHPAndStatus
 	coord hl, 9, 7
-	ld bc, $50b
+	lb bc, 5, 11
 	call ClearScreenArea
 	coord hl, 1, 10
 	coord de, 1, 11
@@ -1132,7 +1132,7 @@
 	call PrintText
 .displayYesNoBox
 	coord hl, 13, 9
-	ld bc, $a0e
+	lb bc, 10, 14
 	ld a, TWO_OPTION_MENU
 	ld [wTextBoxID], a
 	call DisplayTextBoxID
@@ -1209,7 +1209,7 @@
 	cp $c8 + SONY1
 	jr nz, .notSony1Battle
 	coord hl, 0, 0  ; sony 1 battle
-	ld bc, $815
+	lb bc, 8, 21
 	call ClearScreenArea
 	call ScrollTrainerPicAfterBattle
 	ld c, 40
@@ -1449,7 +1449,7 @@
 	ld hl, TrainerAboutToUseText
 	call PrintText
 	coord hl, 0, 7
-	ld bc,$0801
+	lb bc, 8, 1
 	ld a,TWO_OPTION_MENU
 	ld [wTextBoxID],a
 	call DisplayTextBoxID
@@ -1484,7 +1484,7 @@
 .next4
 	call ClearSprites
 	coord hl, 0, 0
-	ld bc,$040B
+	lb bc, 4, 11
 	call ClearScreenArea
 	ld b,1
 	call GoPAL_SET
@@ -1886,7 +1886,7 @@
 	xor a
 	ld [H_AUTOBGTRANSFERENABLED], a
 	coord hl, 9, 7
-	ld bc, $50b
+	lb bc, 5, 11
 	call ClearScreenArea
 	callab PlacePlayerHUDTiles
 	coord hl, 18, 9
@@ -1947,7 +1947,7 @@
 	xor a
 	ld [H_AUTOBGTRANSFERENABLED], a
 	coord hl, 0, 0
-	ld bc, $40c
+	lb bc, 4, 12
 	call ClearScreenArea
 	callab PlaceEnemyHUDTiles
 	ld de, wEnemyMonNick
@@ -2055,11 +2055,11 @@
 .loop
 	inc de
 	ld a, [de]
-	cp $50
+	cp "@"
 	jr z, .done
 	inc de
 	ld a, [de]
-	cp $50
+	cp "@"
 	jr z, .done
 	dec hl
 	dec b
@@ -2091,7 +2091,7 @@
 ; the following happens for the old man tutorial
 	ld hl, wPlayerName
 	ld de, W_GRASSRATE
-	ld bc, $b
+	ld bc, 11
 	call CopyData  ; temporarily save the player name in unused space,
 	               ; which is supposed to get overwritten when entering a
 	               ; map with wild Pokémon. Due to an oversight, the data
@@ -2099,7 +2099,7 @@
 	               ; Missingno. glitch can show up.
 	ld hl, .oldManName
 	ld de, wPlayerName
-	ld bc, $b
+	ld bc, 11
 	call CopyData
 ; the following simulates the keystrokes by drawing menus on screen
 	coord hl, 9, 14
@@ -2106,7 +2106,7 @@
 	ld [hl], "▶"
 	ld c, 80
 	call DelayFrames
-	ld [hl], $7f
+	ld [hl], " "
 	coord hl, 9, 16
 	ld [hl], "▶"
 	ld c, 50
@@ -2395,7 +2395,7 @@
 .partyMonDeselected
 	coord hl, 11, 11
 	ld bc, $81
-	ld a, $7f
+	ld a, " "
 	call FillMemory
 	xor a ; NORMAL_PARTY_MENU
 	ld [wPartyMenuTypeOrMessageID], a
@@ -2585,7 +2585,7 @@
 .relearnmenu
 	ld a, [wWhichPokemon]
 	ld hl, wPartyMon1Moves
-	ld bc, $2c
+	ld bc, wPartyMon2 - wPartyMon1
 	call AddNTimes
 	call .loadmoves
 	coord hl, 4, 7
@@ -2662,7 +2662,7 @@
 	jr z, .select
 	coord hl, 5, 13
 	dec a
-	ld bc, $14
+	ld bc, SCREEN_WIDTH
 	call AddNTimes
 	ld [hl], $ec
 .select
@@ -2862,7 +2862,7 @@
 	push hl
 	call .swapBytes ; swap moves
 	pop hl
-	ld bc, $15
+	ld bc, wPartyMon1PP - wPartyMon1Moves
 	add hl, bc
 	call .swapBytes ; swap move PP
 	xor a
@@ -6318,7 +6318,7 @@
 	call GetMonName
 	ld hl, wcd6d
 	ld de, wEnemyMonNick
-	ld bc, $b
+	ld bc, 11
 	call CopyData
 	ld a, [wEnemyMonSpecies2]
 	ld [wd11e], a
@@ -6718,11 +6718,11 @@
 .lcdEnabled
 	ld de, BattleHudTiles1
 	ld hl, vChars2 + $6d0
-	ld bc, (BANK(BattleHudTiles1) << 8) + $03
+	lb bc, BANK(BattleHudTiles1), $03
 	call CopyVideoDataDouble
 	ld de, BattleHudTiles2
 	ld hl, vChars2 + $730
-	ld bc, (BANK(BattleHudTiles2) << 8) + $06
+	lb bc, BANK(BattleHudTiles2), $06
 	jp CopyVideoDataDouble
 
 PrintEmptyString: ; 3ee94 (f:6e94)
@@ -6942,10 +6942,10 @@
 	ld [H_AUTOBGTRANSFERDEST + 1], a
 	call LoadScreenTilesFromBuffer1
 	coord hl, 9, 7
-	ld bc, $50a
+	lb bc, 5, 10
 	call ClearScreenArea
 	coord hl, 1, 0
-	ld bc, $40a
+	lb bc, 4, 10
 	call ClearScreenArea
 	call ClearSprites
 	ld a, [W_ISINBATTLE]
@@ -7089,8 +7089,8 @@
 	ld a, [wBattleMonSpecies2]
 	ld [wcf91], a
 	coord hl, 1, 5
-	ld b, $7
-	ld c, $8
+	ld b, 7
+	ld c, 8
 	call ClearScreenArea
 	ld hl,  W_MONHBACKSPRITE - W_MONHEADER
 	call UncompressMonSprite
@@ -7928,7 +7928,7 @@
 
 PrintStatText: ; 3f688 (f:7688)
 	ld hl, StatsTextStrings
-	ld c, $50
+	ld c, "@"
 .asm_3f68d
 	dec b
 	jr z, .asm_3f696
--- a/engine/battle/draw_hud_pokeball_gfx.asm
+++ b/engine/battle/draw_hud_pokeball_gfx.asm
@@ -13,7 +13,7 @@
 LoadPartyPokeballGfx: ; 3a85d (e:685d)
 	ld de, PokeballTileGraphics
 	ld hl, vSprites + $310
-	ld bc, (BANK(PokeballTileGraphics) << 8) + $04
+	lb bc, BANK(PokeballTileGraphics), $04
 	jp CopyVideoData
 
 SetupOwnPartyPokeballs: ; 3a869 (e:6869)
--- a/engine/battle/ghost_marowak_anim.asm
+++ b/engine/battle/ghost_marowak_anim.asm
@@ -5,7 +5,7 @@
 	call CopyMonPicFromBGToSpriteVRAM ; cover the BG ghost pic with a sprite ghost pic that looks the same
 ; now that the ghost pic is being displayed using sprites, clear the ghost pic from the BG tilemap
 	coord hl, 12, 0
-	ld bc, $707
+	lb bc, 7, 7
 	call ClearScreenArea
 	call Delay3
 	xor a
@@ -59,7 +59,7 @@
 	ld a, $70
 	ld [W_BASECOORDX], a
 	ld hl, wOAMBuffer
-	ld bc, $606
+	lb bc, 6, 6
 	ld d, $8
 .oamLoop
 	push bc
--- a/engine/battle/trainer_ai.asm
+++ b/engine/battle/trainer_ai.asm
@@ -665,7 +665,7 @@
 	inc d
 .Fainted
 	push bc
-	ld bc,$2C
+	ld bc, wEnemyMon2 - wEnemyMon1
 	add hl,bc
 	pop bc
 	dec c
--- a/engine/cable_club.asm
+++ b/engine/cable_club.asm
@@ -96,7 +96,7 @@
 	ld a, SERIAL_PATCH_LIST_PART_TERMINATOR
 	ld [de], a ; end of part 1
 	inc de
-	ld bc, $100
+	lb bc, 1, 0
 	jr .patchPartyMonsLoop
 .finishedPatchingPlayerData
 	ld a, SERIAL_PATCH_LIST_PART_TERMINATOR
@@ -400,7 +400,7 @@
 	ld a, 1
 	ld [wTopMenuItemX], a
 	coord hl, 1, 1
-	ld bc, $0601
+	lb bc, 6, 1
 	call ClearScreenArea
 .playerMonMenu_HandleInput
 	ld hl, hFlags_0xFFF6
@@ -713,7 +713,7 @@
 	call TextCommandProcessor
 	call SaveScreenTilesToBuffer1
 	coord hl, 10, 7
-	ld bc, $080b
+	lb bc, 8, 11
 	ld a, TRADE_CANCEL_MENU
 	ld [wTwoOptionMenuID], a
 	ld a, TWO_OPTION_MENU
--- a/engine/clear_save.asm
+++ b/engine/clear_save.asm
@@ -6,7 +6,7 @@
 	ld hl, ClearSaveDataText
 	call PrintText
 	coord hl, 14, 7
-	ld bc, $80f
+	lb bc, 8, 15
 	ld a, NO_YES_MENU
 	ld [wTwoOptionMenuID], a
 	ld a, TWO_OPTION_MENU
--- a/engine/evolution.asm
+++ b/engine/evolution.asm
@@ -48,7 +48,7 @@
 	call DelayFrames
 	ld c, $1
 	call EvolutionSetWholeScreenPalette
-	ld bc, $110
+	lb bc, $1, $10
 .animLoop
 	push bc
 	call Evolution_CheckForCancel
--- a/engine/evos_moves.asm
+++ b/engine/evos_moves.asm
@@ -278,7 +278,7 @@
 	cp $50
 	jr nz, .compareNamesLoop
 	ld a, [wWhichPokemon]
-	ld bc, $b
+	ld bc, 11
 	ld hl, wPartyMonNicks
 	call AddNTimes
 	push hl
--- a/engine/gamefreak.asm
+++ b/engine/gamefreak.asm
@@ -5,15 +5,15 @@
 	ld [rOBP1], a
 	ld de, AnimationTileset2 + $30 ; star tile (top left quadrant)
 	ld hl, vChars1 + $200
-	ld bc, (BANK(AnimationTileset2) << 8) + $01
+	lb bc, BANK(AnimationTileset2), $01
 	call CopyVideoData
 	ld de, AnimationTileset2 + $130 ; star tile (bottom left quadrant)
 	ld hl, vChars1 + $210
-	ld bc, (BANK(AnimationTileset2) << 8) + $01
+	lb bc, BANK(AnimationTileset2), $01
 	call CopyVideoData
 	ld de, FallingStar
 	ld hl, vChars1 + $220
-	ld bc, (BANK(FallingStar) << 8) + $01
+	lb bc, BANK(FallingStar), $01
 	call CopyVideoData
 	ld hl, GameFreakLogoOAMData
 	ld de, wOAMBuffer + $60
@@ -31,7 +31,7 @@
 
 ; Move the big star down and left across the screen.
 	ld hl, wOAMBuffer
-	ld bc, $a004
+	lb bc, $a0, $4
 .bigStarLoop
 	push hl
 	push bc
--- a/engine/hall_of_fame.asm
+++ b/engine/hall_of_fame.asm
@@ -8,7 +8,7 @@
 	call DisableLCD
 	ld hl,vBGMap0
 	ld bc, $800
-	ld a, $7f
+	ld a, " "
 	call FillMemory
 	call EnableLCD
 	ld hl, rLCDC
@@ -187,7 +187,7 @@
 	ld a, BANK(RedPicFront)
 	call UncompressSpriteFromDE
 	ld hl, S_SPRITEBUFFER1
-	ld de, $a000
+	ld de, S_SPRITEBUFFER0
 	ld bc, $310
 	call CopyData
 	ld de, vFrontPic
--- a/engine/hidden_object_functions17.asm
+++ b/engine/hidden_object_functions17.asm
@@ -194,7 +194,7 @@
 	ld hl, wd730
 	set 6, [hl]
 	coord hl, 0, 0
-	ld bc, $060a
+	lb bc, 6, 10
 	call TextBoxBorder
 	coord hl, 1, 2
 	ld de, StatusAilmentText1
--- a/engine/hp_bar.asm
+++ b/engine/hp_bar.asm
@@ -222,7 +222,7 @@
 .next
 	add hl, de
 	push hl
-	ld a, $7f
+	ld a, " "
 	ld [hli], a
 	ld [hli], a
 	ld [hli], a
--- a/engine/in_game_trades.asm
+++ b/engine/in_game_trades.asm
@@ -17,7 +17,7 @@
 	ld a,[hli]
 	push af
 	ld de,wInGameTradeMonNick
-	ld bc,$000b
+	ld bc, 11
 	call CopyData
 	pop af
 	ld l,a
@@ -81,7 +81,7 @@
 	call GetMonName
 	ld hl,wcd6d
 	pop de
-	ld bc,$b
+	ld bc, 11
 	jp CopyData
 
 INCLUDE "data/trades.asm"
@@ -105,7 +105,7 @@
 	jr nz,.tradeFailed ; jump if the selected mon's species is not the required one
 	ld a,[wWhichPokemon]
 	ld hl,wPartyMon1Level
-	ld bc,$002c
+	ld bc, wPartyMon2 - wPartyMon1
 	call AddNTimes
 	ld a,[hl]
 	ld [W_CURENEMYLVL],a
@@ -168,11 +168,11 @@
 	ld a, [wInGameTradeReceiveMonSpecies]
 	ld [hl], a ; wTradedEnemyMonSpecies
 	ld hl, wPartyMonOT
-	ld bc, $b
+	ld bc, 11
 	ld a, [wWhichPokemon]
 	call AddNTimes
 	ld de, wTradedPlayerMonOT
-	ld bc, $b
+	ld bc, 11
 	call InGameTrade_CopyData
 	ld hl, InGameTrade_TrainerString
 	ld de, wTradedEnemyMonOT
@@ -201,16 +201,16 @@
 
 InGameTrade_CopyDataToReceivedMon: ; 71d19 (1c:5d19)
 	ld hl, wPartyMonNicks
-	ld bc, $b
+	ld bc, 11
 	call InGameTrade_GetReceivedMonPointer
 	ld hl, wInGameTradeMonNick
-	ld bc, $b
+	ld bc, 11
 	call CopyData
 	ld hl, wPartyMonOT
-	ld bc, $b
+	ld bc, 11
 	call InGameTrade_GetReceivedMonPointer
 	ld hl, InGameTrade_TrainerString
-	ld bc, $b
+	ld bc, 11
 	call CopyData
 	ld hl, wPartyMon1OTID
 	ld bc, wPartyMon2 - wPartyMon1
--- a/engine/intro.asm
+++ b/engine/intro.asm
@@ -28,7 +28,7 @@
 	ld [W_BASECOORDX], a
 	ld a, 80
 	ld [W_BASECOORDY], a
-	ld bc, $606
+	lb bc, 6, 6
 	call InitIntroNidorinoOAM
 	ld de, $28ff ; move Nidorino right by 80 pixels
 	call IntroMoveMon
--- a/engine/items/items.asm
+++ b/engine/items/items.asm
@@ -734,22 +734,22 @@
 	ld bc,4
 	add hl,bc ; hl now points to status
 	ld a,[wcf91]
-	ld bc, (ANTIDOTE_MSG << 8) | (1 << PSN)
+	lb bc, ANTIDOTE_MSG, 1 << PSN
 	cp a,ANTIDOTE
 	jr z,.checkMonStatus
-	ld bc, (BURN_HEAL_MSG << 8) | (1 << BRN)
+	lb bc, BURN_HEAL_MSG, 1 << BRN
 	cp a,BURN_HEAL
 	jr z,.checkMonStatus
-	ld bc, (ICE_HEAL_MSG << 8) | (1 << FRZ)
+	lb bc, ICE_HEAL_MSG, 1 << FRZ
 	cp a,ICE_HEAL
 	jr z,.checkMonStatus
-	ld bc, (AWAKENING_MSG << 8) | SLP
+	lb bc, AWAKENING_MSG, SLP
 	cp a,AWAKENING
 	jr z,.checkMonStatus
-	ld bc, (PARALYZ_HEAL_MSG << 8) | (1 << PAR)
+	lb bc, PARALYZ_HEAL_MSG, 1 << PAR
 	cp a,PARLYZ_HEAL
 	jr z,.checkMonStatus
-	ld bc, (FULL_HEAL_MSG << 8) | $ff ; Full Heal
+	lb bc, FULL_HEAL_MSG, $ff ; Full Heal
 .checkMonStatus
 	ld a,[hl] ; pokemon's status
 	and c ; does the pokemon have a status ailment the item can cure?
@@ -1737,7 +1737,7 @@
 ItemUseOldRod: ; e24c (3:624c)
 	call FishingInit
 	jp c, ItemUseNotTime
-	ld bc, (5 << 8) | MAGIKARP
+	lb bc, 5, MAGIKARP
 	ld a, $1 ; set bite
 	jr RodResponse
 
@@ -2088,7 +2088,7 @@
 	ld hl,TeachMachineMoveText
 	call PrintText
 	coord hl, 14, 7
-	ld bc,$080f
+	lb bc, 8, 15
 	ld a,TWO_OPTION_MENU
 	ld [wTextBoxID],a
 	call DisplayTextBoxID ; yes/no menu
@@ -2479,7 +2479,7 @@
 	ld hl,IsItOKToTossItemText
 	call PrintText
 	coord hl, 14, 7
-	ld bc,$080f
+	lb bc, 8, 15
 	ld a,TWO_OPTION_MENU
 	ld [wTextBoxID],a
 	call DisplayTextBoxID ; yes/no menu
@@ -2578,7 +2578,7 @@
 	jr nz, .asm_e7b1
 	call GetMonHeader
 	ld hl, wBoxMonOT
-	ld bc, $b
+	ld bc, 11
 	ld a, [W_NUMINBOX]
 	dec a
 	jr z, .asm_e7ee
@@ -2585,7 +2585,7 @@
 	dec a
 	call AddNTimes
 	push hl
-	ld bc, $b
+	ld bc, 11
 	add hl, bc
 	ld d, h
 	ld e, l
@@ -2596,7 +2596,7 @@
 .asm_e7db
 	push bc
 	push hl
-	ld bc, $b
+	ld bc, 11
 	call CopyData
 	pop hl
 	ld d, h
@@ -2609,17 +2609,17 @@
 .asm_e7ee
 	ld hl, wPlayerName
 	ld de, wBoxMonOT
-	ld bc, $b
+	ld bc, 11
 	call CopyData
 	ld a, [W_NUMINBOX]
 	dec a
 	jr z, .asm_e82a
 	ld hl, wBoxMonNicks
-	ld bc, $b
+	ld bc, 11
 	dec a
 	call AddNTimes
 	push hl
-	ld bc, $b
+	ld bc, 11
 	add hl, bc
 	ld d, h
 	ld e, l
@@ -2630,7 +2630,7 @@
 .asm_e817
 	push bc
 	push hl
-	ld bc, $b
+	ld bc, 11
 	call CopyData
 	pop hl
 	ld d, h
--- a/engine/learn_move.asm
+++ b/engine/learn_move.asm
@@ -5,7 +5,7 @@
 	call GetPartyMonName
 	ld hl, wcd6d
 	ld de, wd036
-	ld bc, $b
+	ld bc, 11
 	call CopyData
 
 DontAbandonLearning: ; 6e5b (1:6e5b)
@@ -77,7 +77,7 @@
 	ld hl, AbandonLearningText
 	call PrintText
 	coord hl, 14, 7
-	ld bc, $80f
+	lb bc, 8, 15
 	ld a, TWO_OPTION_MENU
 	ld [wTextBoxID], a
 	call DisplayTextBoxID ; yes/no menu
@@ -100,7 +100,7 @@
 	ld hl, TryingToLearnText
 	call PrintText
 	coord hl, 14, 7
-	ld bc, $80f
+	lb bc, 8, 15
 	ld a, TWO_OPTION_MENU
 	ld [wTextBoxID], a
 	call DisplayTextBoxID ; yes/no menu
--- a/engine/load_pokedex_tiles.asm
+++ b/engine/load_pokedex_tiles.asm
@@ -3,9 +3,9 @@
 	call LoadHpBarAndStatusTilePatterns
 	ld de,PokedexTileGraphics
 	ld hl,vChars2 + $600
-	ld bc,(BANK(PokedexTileGraphics) << 8) + $12
+	lb bc, BANK(PokedexTileGraphics), $12
 	call CopyVideoData
 	ld de,PokeballTileGraphics
 	ld hl,vChars2 + $720
-	ld bc,(BANK(PokeballTileGraphics) << 8) + $01
+	lb bc, BANK(PokeballTileGraphics), $01
 	jp CopyVideoData ; load pokeball tile for marking caught mons
--- a/engine/menu/bills_pc.asm
+++ b/engine/menu/bills_pc.asm
@@ -116,7 +116,7 @@
 	ld [wCurrentMenuItem], a
 	ld hl, vChars2 + $780
 	ld de, PokeballTileGraphics
-	ld bc, (BANK(PokeballTileGraphics) << 8) + $01
+	lb bc, BANK(PokeballTileGraphics), $01
 	call CopyVideoData
 	call LoadScreenTilesFromBuffer2DisableBGTransfer
 	coord hl, 0, 0
--- a/engine/menu/diploma.asm
+++ b/engine/menu/diploma.asm
@@ -13,7 +13,7 @@
 	ld a, BANK(CircleTile)
 	call FarCopyData2
 	coord hl, 0, 0
-	ld bc, $1012
+	lb bc, 16, 18
 	predef Diploma_TextBoxBorder
 	ld hl, DiplomaTextPointersAndCoords
 	ld c, $5
@@ -41,7 +41,7 @@
 ; Move the player 33 pixels right and set the priority bit so he appears
 ; behind the background layer.
 	ld hl, wOAMBuffer + $01
-	ld bc, $8028
+	lb bc, $80, $28
 .adjustPlayerGfxLoop
 	ld a, [hl] ; X
 	add 33
--- a/engine/menu/league_pc.asm
+++ b/engine/menu/league_pc.asm
@@ -90,7 +90,7 @@
 	ld a, [hli]
 	ld [wHoFMonLevel], a
 	ld de, wcd6d
-	ld bc, $000B
+	ld bc, 11
 	call CopyData
 	ld b, $0B
 	ld c, 0
--- a/engine/menu/naming_screen.asm
+++ b/engine/menu/naming_screen.asm
@@ -5,8 +5,8 @@
 	ld a, [W_ISINBATTLE]
 	dec a
 	coord hl, 0, 0
-	ld b, $4
-	ld c, $b
+	ld b, 4
+	ld c, 11
 	call z, ClearScreenArea ; only if in wild batle
 	ld a, [wcf91]
 	ld [wd11e], a
@@ -14,7 +14,7 @@
 	ld hl, DoYouWantToNicknameText
 	call PrintText
 	coord hl, 14, 7
-	ld bc, $80f
+	lb bc, 8, 15
 	ld a, TWO_OPTION_MENU
 	ld [wTextBoxID], a
 	call DisplayTextBoxID
@@ -64,10 +64,10 @@
 	call RestoreScreenTilesAndReloadTilePatterns
 	call LoadGBPal
 	ld a, [wcf4b]
-	cp $50
+	cp "@"
 	jr z, .playerCancelled
 	ld hl, wPartyMonNicks
-	ld bc, $b
+	ld bc, 11
 	ld a, [wWhichPokemon]
 	call AddNTimes
 	ld e, l
@@ -269,7 +269,7 @@
 	ret z
 	call CalcStringLength
 	dec hl
-	ld [hl], $50
+	ld [hl], "@"
 	ret
 .pressedRight
 	ld a, [wCurrentMenuItem]
@@ -342,7 +342,7 @@
 	ld de, UpperCaseAlphabet
 .lowercase
 	coord hl, 2, 5
-	ld bc, $509 ; 5 rows, 9 columns
+	lb bc, 5, 9 ; 5 rows, 9 columns
 .outerLoop
 	push bc
 .innerLoop
@@ -373,7 +373,7 @@
 	ld a, c
 	ld [wNamingScreenNameLength], a
 	coord hl, 10, 2
-	ld bc, $10a
+	lb bc, 1, 10
 	call ClearScreenArea
 	coord hl, 10, 2
 	ld de, wcf4b
@@ -458,7 +458,7 @@
 	ld c, $0
 .loop
 	ld a, [hl]
-	cp $50
+	cp "@"
 	ret z
 	inc hl
 	inc c
--- a/engine/menu/pokedex.asm
+++ b/engine/menu/pokedex.asm
@@ -120,7 +120,7 @@
 	push bc
 	coord hl, 0, 3
 	ld de,20
-	ld bc,$7f0d ; 13 blank tiles
+	lb bc, " ", 13
 	call DrawTileLine ; cover up the menu cursor in the pokemon list
 	pop bc
 	ret
@@ -128,7 +128,7 @@
 	push bc
 	coord hl, 15, 10
 	ld de,20
-	ld bc,$7f07 ; 7 blank tiles
+	lb bc, " ", 7
 	call DrawTileLine ; cover up the menu cursor in the side menu
 	pop bc
 	jr .exitSideMenu
@@ -212,7 +212,7 @@
 	xor a
 	ld [H_AUTOBGTRANSFERENABLED],a
 	coord hl, 4, 2
-	ld bc,$0e0a
+	lb bc, 14, 10
 	call ClearScreenArea
 	coord hl, 1, 3
 	ld a,[wListScrollOffset]
@@ -413,14 +413,14 @@
 	ld [hTilesetType],a
 	coord hl, 0, 0
 	ld de,1
-	ld bc,$6414
+	lb bc, $64, SCREEN_WIDTH
 	call DrawTileLine ; draw top border
 	coord hl, 0, 17
-	ld b,$6f
+	ld b, $6f
 	call DrawTileLine ; draw bottom border
 	coord hl, 0, 1
 	ld de,20
-	ld bc,$6610
+	lb bc, $66, $10
 	call DrawTileLine ; draw left border
 	coord hl, 19, 1
 	ld b,$67
--- a/engine/menu/start_sub_menus.asm
+++ b/engine/menu/start_sub_menus.asm
@@ -34,7 +34,7 @@
 	ld [wTextBoxID],a
 	call DisplayTextBoxID ; display pokemon menu options
 	ld hl,wFieldMoves
-	ld bc,$020c ; max menu item ID, top menu item Y
+	lb bc, $02, $0c ; max menu item ID, top menu item Y
 	ld e,5
 .adjustMenuVariablesLoop
 	dec e
@@ -523,7 +523,7 @@
 ; loads tile patterns and draws everything except for gym leader faces / badges
 DrawTrainerInfo: ; 1349a (4:749a)
 	ld de,RedPicFront
-	ld bc,(BANK(RedPicFront) << 8) | $01
+	lb bc, BANK(RedPicFront), $01
 	predef DisplayPicCenteredOrUpperRight
 	call DisableLCD
 	coord hl, 0, 2
@@ -632,7 +632,7 @@
 ; [wTrainerInfoTextBoxNextRowOffset] = distance from the end of a text box row to the start of the next
 TrainerInfo_DrawTextBox: ; 135a0 (4:75a0)
 	ld a,$79 ; upper left corner tile ID
-	ld de,$7a7b ; top edge and upper right corner tile ID's
+	lb de, $7a, $7b ; top edge and upper right corner tile ID's
 	call TrainerInfo_DrawHorizontalEdge ; draw top edge
 	call TrainerInfo_NextTextBoxRow
 	ld a,[wTrainerInfoTextBoxWidthPlus1]
@@ -647,7 +647,7 @@
 	dec c
 	jr nz,.loop
 	ld a,$7d ; lower left corner tile ID
-	ld de,$777e ; bottom edge and lower right corner tile ID's
+	lb de,$77, $7e ; bottom edge and lower right corner tile ID's
 
 TrainerInfo_DrawHorizontalEdge: ; 135c3 (4:75c3)
 	ld [hli],a ; place left corner tile
@@ -813,7 +813,7 @@
 	call SkipFixedLengthTextEntries
 	push hl
 	ld de, wSwitchPartyMonTempBuffer
-	ld bc, $b
+	ld bc, 11
 	call CopyData
 	ld hl, wPartyMonOT
 	ld a, [wMenuItemToSwap]
@@ -820,11 +820,11 @@
 	call SkipFixedLengthTextEntries
 	pop de
 	push hl
-	ld bc, $b
+	ld bc, 11
 	call CopyData
 	pop de
 	ld hl, wSwitchPartyMonTempBuffer
-	ld bc, $b
+	ld bc, 11
 	call CopyData
 	ld hl, wPartyMonNicks
 	ld a, [wCurrentMenuItem]
@@ -831,7 +831,7 @@
 	call SkipFixedLengthTextEntries
 	push hl
 	ld de, wSwitchPartyMonTempBuffer
-	ld bc, $b
+	ld bc, 11
 	call CopyData
 	ld hl, wPartyMonNicks
 	ld a, [wMenuItemToSwap]
@@ -838,11 +838,11 @@
 	call SkipFixedLengthTextEntries
 	pop de
 	push hl
-	ld bc, $b
+	ld bc, 11
 	call CopyData
 	pop de
 	ld hl, wSwitchPartyMonTempBuffer
-	ld bc, $b
+	ld bc, 11
 	call CopyData
 	ld a, [wMenuItemToSwap]
 	ld [wSwappedMenuItem], a
--- a/engine/menu/status_screen.asm
+++ b/engine/menu/status_screen.asm
@@ -87,19 +87,19 @@
 	call LoadHpBarAndStatusTilePatterns
 	ld de, BattleHudTiles1  ; source
 	ld hl, vChars2 + $6d0 ; dest
-	ld bc, (BANK(BattleHudTiles1) << 8) + $03 ; bank bytes/8
+	lb bc, BANK(BattleHudTiles1), $03
 	call CopyVideoDataDouble ; ·│ :L and halfarrow line end
 	ld de, BattleHudTiles2
 	ld hl, vChars2 + $780
-	ld bc, (BANK(BattleHudTiles2) << 8) + $01
+	lb bc, BANK(BattleHudTiles2), $01
 	call CopyVideoDataDouble ; │
 	ld de, BattleHudTiles3
 	ld hl, vChars2 + $760
-	ld bc, (BANK(BattleHudTiles3) << 8) + $02
+	lb bc, BANK(BattleHudTiles3), $02
 	call CopyVideoDataDouble ; ─┘
 	ld de, PTile
 	ld hl, vChars2 + $720
-	ld bc,(BANK(PTile) << 8 | $01)
+	lb bc, BANK(PTile), $01
 	call CopyVideoDataDouble ; P (for PP), inline
 	ld a, [hTilesetType]
 	push af
@@ -106,15 +106,15 @@
 	xor a
 	ld [hTilesetType], a
 	coord hl, 19, 1
-	ld bc, $060a
+	lb bc, 6, 10
 	call DrawLineBox ; Draws the box around name, HP and status
-	ld de, $fffa
+	ld de, -6
 	add hl, de
 	ld [hl], $f2 ; . after No ("." is a different one)
 	dec hl
 	ld [hl], "№"
 	coord hl, 19, 9
-	ld bc, $0806
+	lb bc, 8, 6
 	call DrawLineBox ; Draws the box around types, ID No. and OT
 	coord hl, 10, 9
 	ld de, Type1Text
@@ -224,7 +224,7 @@
 
 ; Draws a line starting from hl high b and wide c
 DrawLineBox: ; 0x12ac7
-	ld de, $0014 ; New line
+	ld de, SCREEN_WIDTH ; New line
 .PrintVerticalLine
 	ld [hl], $78 ; │
 	add hl, de
--- a/engine/oak_speech.asm
+++ b/engine/oak_speech.asm
@@ -24,11 +24,11 @@
 	call z, InitOptions
 	ld hl, NintenText
 	ld de, wPlayerName
-	ld bc, $b
+	ld bc, 11
 	call CopyData
 	ld hl, SonyText
 	ld de, W_RIVALNAME
-	ld bc, $b
+	ld bc, 11
 	jp CopyData
 
 OakSpeech: ; 6115 (1:6115)
@@ -57,7 +57,7 @@
 	bit 1,a ; possibly a debug mode bit
 	jp nz,.skipChoosingNames
 	ld de,ProfOakPic
-	ld bc, (Bank(ProfOakPic) << 8) | $00
+	lb bc, Bank(ProfOakPic), $00
 	call IntroDisplayPicCenteredOrUpperRight
 	call FadeInIntroPic
 	ld hl,OakSpeechText1
@@ -76,7 +76,7 @@
 	call GBFadeOutToWhite
 	call ClearScreen
 	ld de,RedPicFront
-	ld bc,(Bank(RedPicFront) << 8) | $00
+	lb bc, Bank(RedPicFront), $00
 	call IntroDisplayPicCenteredOrUpperRight
 	call MovePicLeft
 	ld hl,IntroducePlayerText
@@ -85,7 +85,7 @@
 	call GBFadeOutToWhite
 	call ClearScreen
 	ld de,Rival1Pic
-	ld bc,(Bank(Rival1Pic) << 8) | $00
+	lb bc, Bank(Rival1Pic), $00
 	call IntroDisplayPicCenteredOrUpperRight
 	call FadeInIntroPic
 	ld hl,IntroduceRivalText
@@ -95,7 +95,7 @@
 	call GBFadeOutToWhite
 	call ClearScreen
 	ld de,RedPicFront
-	ld bc,(Bank(RedPicFront) << 8) | $00
+	lb bc, Bank(RedPicFront), $00
 	call IntroDisplayPicCenteredOrUpperRight
 	call GBFadeInFromWhite
 	ld a,[wd72d]
@@ -115,15 +115,15 @@
 	call DelayFrames
 	ld de,RedSprite
 	ld hl,vSprites
-	ld bc,(BANK(RedSprite) << 8) | $0C
+	lb bc, BANK(RedSprite), $0C
 	call CopyVideoData
 	ld de,ShrinkPic1
-	ld bc,(BANK(ShrinkPic1) << 8) | $00
+	lb bc, BANK(ShrinkPic1), $00
 	call IntroDisplayPicCenteredOrUpperRight
 	ld c,4
 	call DelayFrames
 	ld de,ShrinkPic2
-	ld bc,(BANK(ShrinkPic2) << 8) | $00
+	lb bc, BANK(ShrinkPic2), $00
 	call IntroDisplayPicCenteredOrUpperRight
 	call ResetPlayerSpriteData
 	ld a,[H_LOADEDROMBANK]
--- a/engine/oak_speech2.asm
+++ b/engine/oak_speech2.asm
@@ -73,7 +73,7 @@
 	call DelayFrames
 	pop de
 	ld hl, wcd6d
-	ld bc, $b
+	ld bc, 11
 	call CopyData
 	call Delay3
 	coord hl, 12, 4
--- a/engine/overworld/cut.asm
+++ b/engine/overworld/cut.asm
@@ -82,11 +82,11 @@
 ; tree
 	ld de, Overworld_GFX + $2d0 ; cuttable tree sprite top row
 	ld hl, vChars1 + $7c0
-	ld bc, (BANK(Overworld_GFX) << 8) + $02
+	lb bc, BANK(Overworld_GFX), $02
 	call CopyVideoData
 	ld de, Overworld_GFX + $3d0 ; cuttable tree sprite bottom row
 	ld hl, vChars1 + $7e0
-	ld bc, (BANK(Overworld_GFX) << 8) + $02
+	lb bc, BANK(Overworld_GFX), $02
 	call CopyVideoData
 	jr WriteCutOrBoulderDustAnimationOAMBlock
 .grass
@@ -113,7 +113,7 @@
 
 LoadCutGrassAnimationTilePattern: ; f04c (3:704c)
 	ld de, AnimationTileset2 + $60 ; tile depicting a leaf
-	ld bc, (BANK(AnimationTileset2) << 8) + $01
+	lb bc, BANK(AnimationTileset2), $01
 	jp CopyVideoData
 
 WriteCutOrBoulderDustAnimationOAMBlock: ; f055 (3:7055)
--- a/engine/overworld/emotion_bubbles.asm
+++ b/engine/overworld/emotion_bubbles.asm
@@ -9,7 +9,7 @@
 	inc hl
 	ld d, [hl]
 	ld hl, vChars1 + $780
-	ld bc, (BANK(EmotionBubblesPointerTable) << 8) + $04
+	lb bc, BANK(EmotionBubblesPointerTable), $04
 	call CopyVideoData
 	ld a, [wUpdateSpritesEnabled]
 	push af
--- a/engine/overworld/healing_machine.asm
+++ b/engine/overworld/healing_machine.asm
@@ -1,7 +1,7 @@
 AnimateHealingMachine: ; 70433 (1c:4433)
 	ld de, PokeCenterFlashingMonitorAndHealBall
 	ld hl, vChars0 + $7c0
-	ld bc, (BANK(PokeCenterFlashingMonitorAndHealBall) << 8) + $03
+	lb bc, BANK(PokeCenterFlashingMonitorAndHealBall), $03
 	call CopyVideoData
 	ld hl, wUpdateSpritesEnabled
 	ld a, [hl]
--- a/engine/overworld/ledges.asm
+++ b/engine/overworld/ledges.asm
@@ -69,10 +69,10 @@
 LoadHoppingShadowOAM: ; 1a6f0 (6:66f0)
 	ld hl, vChars1 + $7f0
 	ld de, LedgeHoppingShadow
-	ld bc, (BANK(LedgeHoppingShadow) << 8) + $01
+	lb bc, BANK(LedgeHoppingShadow), $01
 	call CopyVideoDataDouble
 	ld a, $9
-	ld bc, $5448 ; b, c = y, x coordinates of shadow
+	lb bc, $54, $48 ; b, c = y, x coordinates of shadow
 	ld de, LedgeHoppingShadowOAM
 	call WriteOAMBlock
 	ret
--- a/engine/overworld/player_animations.asm
+++ b/engine/overworld/player_animations.asm
@@ -47,7 +47,7 @@
 	pop hl
 	ld de, BirdSprite
 	ld hl, vNPCSprites
-	ld bc, (BANK(BirdSprite) << 8) + $0c
+	lb bc, BANK(BirdSprite), $0c
 	call CopyVideoData
 	call LoadBirdSpriteGraphics
 	ld a, SFX_FLY
@@ -250,11 +250,11 @@
 LoadBirdSpriteGraphics: ; 706d7 (1c:46d7)
 	ld de, BirdSprite
 	ld hl, vNPCSprites
-	ld bc, (BANK(BirdSprite) << 8) + $0c
+	lb bc, BANK(BirdSprite), $0c
 	call CopyVideoData
 	ld de, BirdSprite + $c0 ; moving animation sprite
 	ld hl, vNPCSprites2
-	ld bc, (BANK(BirdSprite) << 8) + $0c
+	lb bc, BANK(BirdSprite), $0c
 	jp CopyVideoData
 
 InitFacingDirectionList: ; 706ef (1c:46ef)
@@ -388,7 +388,7 @@
 	set 6, [hl] ; reserve the last 4 OAM entries
 	ld de, RedSprite
 	ld hl, vNPCSprites
-	ld bc, (BANK(RedSprite) << 8) + $0c
+	lb bc, BANK(RedSprite), $0c
 	call CopyVideoData
 	ld a, $4
 	ld hl, RedFishingTiles
--- a/engine/overworld/pokemart.asm
+++ b/engine/overworld/pokemart.asm
@@ -82,10 +82,10 @@
 	inc a
 	jr z,.sellMenuLoop ; if the player closed the choose quantity menu with the B button
 	ld hl,PokemartTellSellPriceText
-	ld bc,$0e01
+	lb bc, 14, 1 ; location that PrintText always prints to, this is useless
 	call PrintText
 	coord hl, 14, 7
-	ld bc,$080f
+	lb bc, 08, 15
 	ld a,TWO_OPTION_MENU
 	ld [wTextBoxID],a
 	call DisplayTextBoxID ; yes/no menu
@@ -163,7 +163,7 @@
 	ld hl,PokemartTellBuyPriceText
 	call PrintText
 	coord hl, 14, 7
-	ld bc,$080f
+	lb bc, 8, 15
 	ld a,TWO_OPTION_MENU
 	ld [wTextBoxID],a
 	call DisplayTextBoxID ; yes/no menu
--- a/engine/overworld/ssanne.asm
+++ b/engine/overworld/ssanne.asm
@@ -85,7 +85,7 @@
 
 LoadSmokeTile: ; 79fd4 (1e:5fd4)
 	ld de, SSAnneSmokePuffTile
-	ld bc, (BANK(SSAnneSmokePuffTile) << 8) + $01
+	lb bc, BANK(SSAnneSmokePuffTile), $01
 	jp CopyVideoData
 
 SSAnneSmokePuffTile: ; 79fdd (1e:5fdd)
--- a/engine/save.asm
+++ b/engine/save.asm
@@ -155,8 +155,8 @@
 .save
 	call SaveSAVtoSRAM
 	coord hl, 1, 13
-	ld bc,$0412
-	call ClearScreenArea ; clear area 4x12 starting at 13,1
+	lb bc, 4, 18
+	call ClearScreenArea
 	coord hl, 1, 14
 	ld de,NowSavingString
 	call PlaceString
@@ -176,7 +176,7 @@
 SaveSAVConfirm: ; 73768 (1c:7768)
 	call PrintText
 	coord hl, 0, 7
-	ld bc,$0801
+	lb bc, 8, 1
 	ld a,TWO_OPTION_MENU
 	ld [wTextBoxID],a
 	call DisplayTextBoxID ; yes/no menu
--- a/engine/slot_machine.asm
+++ b/engine/slot_machine.asm
@@ -134,7 +134,7 @@
 	ld hl, OneMoreGoSlotMachineText
 	call PrintText
 	coord hl, 14, 12
-	ld bc, $0d0f
+	lb bc, 13, 15
 	xor a ; YES_NO_MENU
 	ld [wTwoOptionMenuID], a
 	ld a, TWO_OPTION_MENU
--- a/engine/titlescreen.asm
+++ b/engine/titlescreen.asm
@@ -1,6 +1,6 @@
 ; copy text of fixed length $b (like player name, rival name, mon names, ...)
 CopyFixedLengthText: ; 42b1 (1:42b1)
-	ld bc, $b
+	ld bc, 11
 	jp CopyData
 
 SetDefaultNamesBeforeTitlescreen: ; 42b7 (1:42b7)
@@ -377,7 +377,7 @@
 LoadCopyrightTiles: ; 4541 (1:4541)
 	ld de, NintendoCopyrightLogoGraphics
 	ld hl, vChars2 + $600
-	ld bc, (BANK(NintendoCopyrightLogoGraphics) << 8) + $1c
+	lb bc, BANK(NintendoCopyrightLogoGraphics), $1c
 	call CopyVideoData
 	coord hl, 2, 7
 	ld de, CopyrightTextString
--- a/engine/town_map.asm
+++ b/engine/town_map.asm
@@ -20,7 +20,7 @@
 	call CopyData
 	ld hl, vSprites + $40
 	ld de, TownMapCursor
-	ld bc, (BANK(TownMapCursor) << 8) + $04
+	lb bc, BANK(TownMapCursor), $04
 	call CopyVideoDataDouble
 	xor a
 	ld [wWhichTownMapLocation], a
@@ -29,7 +29,7 @@
 
 .townMapLoop
 	coord hl, 0, 0
-	ld bc, $114
+	lb bc, 1, 20
 	call ClearScreenArea
 	ld hl, TownMapOrder
 	ld a, [wWhichTownMapLocation]
@@ -140,11 +140,11 @@
 	call LoadFontTilePatterns
 	ld de, BirdSprite
 	ld hl, vSprites + $40
-	ld bc, (BANK(BirdSprite) << 8) + $0c
+	lb bc, BANK(BirdSprite), $0c
 	call CopyVideoData
 	ld de, TownMapUpArrow
 	ld hl, vChars1 + $6d0
-	ld bc, (BANK(TownMapUpArrow) << 8) + $01
+	lb bc, BANK(TownMapUpArrow), $01
 	call CopyVideoDataDouble
 	call BuildFlyLocationsList
 	ld hl, wUpdateSpritesEnabled
@@ -161,12 +161,12 @@
 	ld hl, wFlyLocationsList
 	coord de, 18, 0
 .townMapFlyLoop
-	ld a, $7f
+	ld a, " "
 	ld [de], a
 	push hl
 	push hl
 	coord hl, 3, 0
-	ld bc, $10f
+	lb bc, 1, 15
 	call ClearScreenArea
 	pop hl
 	ld a, [hl]
@@ -442,8 +442,8 @@
 
 WriteTownMapSpriteOAM: ; 71279 (1c:5279)
 	push hl
-	ld hl, $fcfc
-	add hl, bc ; subtract 4 from c (X coord) and 3 from b (Y coord)
+	lb hl, -4, -4
+	add hl, bc ; subtract 4 from c (X coord) and 4 from b (Y coord)
 	ld b, h
 	ld c, l
 	pop hl
@@ -451,7 +451,7 @@
 WriteAsymmetricMonPartySpriteOAM: ; 71281 (1c:5281)
 ; Writes 4 OAM blocks for a helix mon party sprite, since it does not have
 ; a vertical line of symmetry.
-	ld de, $202
+	lb de, 2, 2
 .loop
 	push de
 	push bc
--- a/engine/trade.asm
+++ b/engine/trade.asm
@@ -371,7 +371,7 @@
 	call PlayCry
 	call Trade_Delay100
 	coord hl, 4, 10
-	ld bc, $80c
+	lb bc, 8, 12
 	call ClearScreenArea
 	jp PrintTradeTakeCareText
 
@@ -647,14 +647,14 @@
 	and a
 	jr z, .movingLeft
 ; moving right
-	ld bc, $400 ; move right
+	lb bc, 4, 0 ; move right
 	call .doAnim
-	ld bc, $a ; move down
+	lb bc, 0, 10 ; move down
 	jr .doAnim
 .movingLeft
-	ld bc, $f6 ; move up
+	lb bc, 0, -10 ; move up
 	call .doAnim
-	ld bc, $fc00 ; move left
+	lb bc, -4, 0 ; move left
 .doAnim
 	ld a, b
 	ld [W_BASECOORDX], a
--- a/home/copy2.asm
+++ b/home/copy2.asm
@@ -161,7 +161,7 @@
 
 ClearScreenArea::
 ; Clear tilemap area cxb at hl.
-	ld a, $7f ; blank tile
+	ld a, " " ; blank tile
 	ld de, 20 ; screen width
 .y
 	push hl
@@ -218,7 +218,7 @@
 	ld bc, 20 * 18
 	inc b
 	coord hl, 0, 0
-	ld a, $7f
+	ld a, " "
 .loop
 	ld [hli], a
 	dec c
--- a/home/overworld.asm
+++ b/home/overworld.asm
@@ -1995,7 +1995,7 @@
 LoadPlayerSpriteGraphicsCommon:: ; 1063 (0:1063)
 	push de
 	push hl
-	ld bc,(BANK(RedSprite) << 8) + $0c
+	lb bc, BANK(RedSprite), $0c
 	call CopyVideoData
 	pop hl
 	pop de
@@ -2006,7 +2006,7 @@
 	inc d
 .noCarry
 	set 3,h
-	ld bc,$050c
+	lb bc, BANK(RedSprite), $0c
 	jp CopyVideoData
 
 ; function to load data from the map header
--- a/home/text.asm
+++ b/home/text.asm
@@ -291,7 +291,7 @@
 	call ProtectedDelay3
 	call ManualTextScroll
 	coord hl, 1, 13
-	ld bc,$0412
+	lb bc, 4, 18
 	call ClearScreenArea
 	ld c,20
 	call DelayFrames
@@ -306,7 +306,7 @@
 	call ProtectedDelay3
 	call ManualTextScroll
 	coord hl, 1, 10
-	ld bc,$0712
+	lb bc, 7, 18
 	call ClearScreenArea
 	ld c,20
 	call DelayFrames
--- a/main.asm
+++ b/main.asm
@@ -590,7 +590,7 @@
 LoadTrainerInfoTextBoxTiles: ; 5ae6 (1:5ae6)
 	ld de, TrainerInfoTextBoxTileGraphics
 	ld hl, vChars2 + $760
-	ld bc, (BANK(TrainerInfoTextBoxTileGraphics) << 8) +$09
+	lb bc, BANK(TrainerInfoTextBoxTileGraphics), $09
 	jp CopyVideoData
 
 INCLUDE "engine/menu/main_menu.asm"
@@ -1435,8 +1435,8 @@
 	ld [wTextBoxID], a
 	call DisplayTextBoxID
 	coord hl, 13, 1
-	ld b, $1
-	ld c, $6
+	ld b, 1
+	ld c, 6
 	call ClearScreenArea
 	coord hl, 12, 1
 	ld de, wPlayerMoney
@@ -1967,7 +1967,7 @@
 .asm_7ba6
 	ld d, h
 	ld e, l
-	ld bc, $b
+	ld bc, 11
 	add hl, bc
 	ld bc, wPartyMonNicks
 	ld a, [wRemoveMonFromBox]
@@ -2007,12 +2007,12 @@
 	jr z, .asm_7bfa
 	ld hl, wBoxMonNicks
 .asm_7bfa
-	ld bc, $b
+	ld bc, 11
 	ld a, [wWhichPokemon]
 	call AddNTimes
 	ld d, h
 	ld e, l
-	ld bc, $b
+	ld bc, 11
 	add hl, bc
 	ld bc, wPokedexOwned
 	ld a, [wRemoveMonFromBox]
@@ -3587,7 +3587,7 @@
 	ld d, h
 	ld e, l
 	ld hl, wPlayerName
-	ld bc, $b
+	ld bc, 11
 	call CopyData
 	ld a, [wMonDataLocation]
 	and a
@@ -3858,7 +3858,7 @@
 	ld hl, wEnemyMonOT
 	ld a, [wWhichPokemon]
 	call SkipFixedLengthTextEntries
-	ld bc, $000b
+	ld bc, 11
 	call CopyData    ; write new mon's OT name (from an enemy mon)
 	ld hl, wPartyMonNicks
 	ld a, [wPartyCount]
@@ -3869,7 +3869,7 @@
 	ld hl, wEnemyMonNicks
 	ld a, [wWhichPokemon]
 	call SkipFixedLengthTextEntries
-	ld bc, $000b
+	ld bc, 11
 	call CopyData    ; write new mon's nickname (from an enemy mon)
 	ld a, [wcf91]
 	ld [wd11e], a
@@ -4000,7 +4000,7 @@
 	ld a, [wWhichPokemon]
 	call SkipFixedLengthTextEntries
 .asm_f5ec
-	ld bc, $b
+	ld bc, 11
 	call CopyData
 	ld a, [wMoveMonType]
 	cp PARTY_TO_DAYCARE
@@ -4030,7 +4030,7 @@
 	ld a, [wWhichPokemon]
 	call SkipFixedLengthTextEntries
 .asm_f62a
-	ld bc, $b
+	ld bc, 11
 	call CopyData
 	pop hl
 	ld a, [wMoveMonType]
--- a/scripts/agatha.asm
+++ b/scripts/agatha.asm
@@ -22,7 +22,7 @@
 
 AgathaScript_76459: ; 76459 (1d:6459)
 	ld [wNewTileBlockID], a
-	ld bc, $2
+	lb bc, 0, 2
 	predef_jump ReplaceTileBlock
 
 AgathaScript_76464: ; 76464 (1d:6464)
--- a/scripts/bikeshop.asm
+++ b/scripts/bikeshop.asm
@@ -19,7 +19,7 @@
 	jr z, .asm_41190
 	ld hl, BikeShopText_1d81f
 	call PrintText
-	ld bc, (BICYCLE << 8) | 1
+	lb bc, BICYCLE, 1
 	call GiveItem
 	jr nc, .BagFull
 	ld a, BIKE_VOUCHER
--- a/scripts/billshouse.asm
+++ b/scripts/billshouse.asm
@@ -163,7 +163,7 @@
 	jr nz, .asm_1e8a9
 	ld hl, BillThankYouText
 	call PrintText
-	ld bc, (S_S__TICKET << 8) | 1
+	lb bc, S_S__TICKET, 1
 	call GiveItem
 	jr nc, .BagFull
 	ld hl, SSTicketReceivedText
--- a/scripts/blueshouse.asm
+++ b/scripts/blueshouse.asm
@@ -36,7 +36,7 @@
 .GiveMap
 	ld hl,DaisyOfferMapText
 	call PrintText
-	ld bc,(TOWN_MAP << 8) | 1
+	lb bc, TOWN_MAP, 1
 	call GiveItem
 	jr nc, .BagFull
 	ld a,HS_TOWN_MAP
--- a/scripts/bruno.asm
+++ b/scripts/bruno.asm
@@ -22,7 +22,7 @@
 
 BrunoScript_76302: ; 76302 (1d:6302)
 	ld [wNewTileBlockID], a
-	ld bc, $2
+	lb bc, 0, 2
 	predef_jump ReplaceTileBlock
 
 BrunoScript_7630d: ; 7630d (1d:630d)
--- a/scripts/celadoncity.asm
+++ b/scripts/celadoncity.asm
@@ -46,7 +46,7 @@
 	jr nz, .asm_7053f
 	ld hl, TM41PreText
 	call PrintText
-	ld bc, (TM_41 << 8) | 1
+	lb bc, TM_41, 1
 	call GiveItem
 	jr c, .Success
 	ld hl, TM41NoRoomText
--- a/scripts/celadondiner.asm
+++ b/scripts/celadondiner.asm
@@ -31,7 +31,7 @@
 	jr nz, .asm_eb14d
 	ld hl, CeladonDinerText_491a7
 	call PrintText
-	ld bc, (COIN_CASE << 8) | 1
+	lb bc, COIN_CASE, 1
 	call GiveItem
 	jr nc, .BagFull
 	SetEvent EVENT_GOT_COIN_CASE
--- a/scripts/celadongamecorner.asm
+++ b/scripts/celadongamecorner.asm
@@ -32,7 +32,7 @@
 	ret nz
 	ld a, $2a
 	ld [wNewTileBlockID], a
-	ld bc, $0208
+	lb bc, 2, 8
 	predef_jump ReplaceTileBlock
 
 CeladonGameCornerScript_48c07: ; 48c07 (12:4c07)
@@ -452,7 +452,7 @@
 	SetEvent EVENT_FOUND_ROCKET_HIDEOUT
 	ld a, $43
 	ld [wNewTileBlockID], a
-	ld bc, $0208
+	lb bc, 2, 8
 	predef ReplaceTileBlock
 	jp TextScriptEnd
 
@@ -477,8 +477,8 @@
 	call TextBoxBorder
 	call UpdateSprites
 	coord hl, 12, 1
-	ld b, $4
-	ld c, $7
+	ld b, 4
+	ld c, 7
 	call ClearScreenArea
 	coord hl, 12, 2
 	ld de, GameCornerMoneyText
--- a/scripts/celadongym.asm
+++ b/scripts/celadongym.asm
@@ -47,7 +47,7 @@
 	ld [hSpriteIndexOrTextID], a
 	call DisplayTextID
 	SetEvent EVENT_BEAT_ERIKA
-	ld bc, (TM_21 << 8) | 1
+	lb bc, TM_21, 1
 	call GiveItem
 	jr nc, .BagFull
 	ld a, $a
--- a/scripts/celadonmansion5.asm
+++ b/scripts/celadonmansion5.asm
@@ -11,7 +11,7 @@
 
 CeladonMansion5Text2: ; 1dd46 (7:5d46)
 	TX_ASM
-	ld bc,(EEVEE << 8) | 25
+	lb bc, EEVEE, 25
 	call GivePokemon
 	jr nc, .asm_24365
 	ld a, HS_CELADON_MANSION_5_GIFT
--- a/scripts/celadonmart3.asm
+++ b/scripts/celadonmart3.asm
@@ -26,7 +26,7 @@
 	jr nz, .asm_a5463
 	ld hl, TM18PreReceiveText
 	call PrintText
-	ld bc, (TM_18 << 8) | 1
+	lb bc, TM_18, 1
 	call GiveItem
 	jr nc, .BagFull
 	SetEvent EVENT_GOT_TM18
--- a/scripts/celadonmartroof.asm
+++ b/scripts/celadonmartroof.asm
@@ -88,7 +88,7 @@
 	ld hl, CeladonMartRoofText_48515
 	call PrintText
 	call RemoveItemByIDBank12
-	ld bc, (TM_49 << 8) | 1
+	lb bc, TM_49, 1
 	call GiveItem
 	jr nc, .BagFull
 	ld hl, ReceivedTM49Text
@@ -101,7 +101,7 @@
 	ld hl, CeladonMartRoofText_48504
 	call PrintText
 	call RemoveItemByIDBank12
-	ld bc, (TM_48 << 8) | 1
+	lb bc, TM_48, 1
 	call GiveItem
 	jr nc, .BagFull
 	ld hl, CeladonMartRoofText_4850a
@@ -114,7 +114,7 @@
 	ld hl, CeladonMartRoofText_484f3
 	call PrintText
 	call RemoveItemByIDBank12
-	ld bc, (TM_13 << 8) | 1
+	lb bc, TM_13, 1
 	call GiveItem
 	jr nc, .BagFull
 	ld hl, CeladonMartRoofText_484f9
--- a/scripts/ceruleancity.asm
+++ b/scripts/ceruleancity.asm
@@ -299,7 +299,7 @@
 .asm_4ca20
 	ld hl, CeruleanCityText_196f3
 	call PrintText
-	ld bc, (TM_28 << 8) + 1
+	lb bc, TM_28, 1
 	call GiveItem
 	jr c, .Success
 	ld hl, TM28NoRoomText
--- a/scripts/ceruleangym.asm
+++ b/scripts/ceruleangym.asm
@@ -47,7 +47,7 @@
 	ld [hSpriteIndexOrTextID], a
 	call DisplayTextID
 	SetEvent EVENT_BEAT_MISTY
-	ld bc, (TM_11 << 8) | 1
+	lb bc, TM_11, 1
 	call GiveItem
 	jr nc, .BagFull
 	ld a, $6
--- a/scripts/cinnabargym.asm
+++ b/scripts/cinnabargym.asm
@@ -144,7 +144,7 @@
 	ld [hSpriteIndexOrTextID], a
 	call DisplayTextID
 	SetEvent EVENT_BEAT_BLAINE
-	ld bc, (TM_38 << 8) | 1
+	lb bc, TM_38, 1
 	call GiveItem
 	jr nc, .BagFull
 	ld a, $b
--- a/scripts/copycatshouse2f.asm
+++ b/scripts/copycatshouse2f.asm
@@ -23,7 +23,7 @@
 	jr z, .asm_62ecd
 	ld hl, TM31PreReceiveText
 	call PrintText
-	ld bc, (TM_31 << 8) | 1
+	lb bc, TM_31, 1
 	call GiveItem
 	jr nc, .BagFull
 	ld hl, ReceivedTM31Text
--- a/scripts/fanclub.asm
+++ b/scripts/fanclub.asm
@@ -113,7 +113,7 @@
 	; tell the story
 	ld hl, .storytext
 	call PrintText
-	ld bc, (BIKE_VOUCHER << 8) | 1
+	lb bc, BIKE_VOUCHER, 1
 	call GiveItem
 	jr nc, .BagFull
 	ld hl, .receivedvouchertext
--- a/scripts/fuchsiagym.asm
+++ b/scripts/fuchsiagym.asm
@@ -47,7 +47,7 @@
 	ld [hSpriteIndexOrTextID], a
 	call DisplayTextID
 	SetEvent EVENT_BEAT_KOGA
-	ld bc, (TM_06 << 8) | 1
+	lb bc, TM_06, 1
 	call GiveItem
 	jr nc, .BagFull
 	ld a, $a
--- a/scripts/fuchsiahouse2.asm
+++ b/scripts/fuchsiahouse2.asm
@@ -38,7 +38,7 @@
 .asm_60cba
 	ld hl, WardenThankYouText
 	call PrintText
-	ld bc,(HM_04 << 8) | 1
+	lb bc, HM_04, 1
 	call GiveItem
 	jr nc, .BagFull
 	ld hl, ReceivedHM04Text
--- a/scripts/fuchsiahouse3.asm
+++ b/scripts/fuchsiahouse3.asm
@@ -18,7 +18,7 @@
 	and a
 	jr nz, .refused
 
-	ld bc, (GOOD_ROD << 8) | 1
+	lb bc, GOOD_ROD, 1
 	call GiveItem
 	jr nc, .full
 
--- a/scripts/lab3.asm
+++ b/scripts/lab3.asm
@@ -14,7 +14,7 @@
 	jr nz, .asm_e551a
 	ld hl, TM35PreReceiveText
 	call PrintText
-	ld bc, (TM_35 << 8) | 1
+	lb bc, TM_35, 1
 	call GiveItem
 	jr nc, .BagFull
 	ld hl, ReceivedTM35Text
--- a/scripts/lance.asm
+++ b/scripts/lance.asm
@@ -25,12 +25,12 @@
 LanceScript_5a2de: ; 5a2de (16:62de)
 	push bc
 	ld [wNewTileBlockID], a
-	ld bc, $602
+	lb bc, 6, 2
 	call LanceScript_5a2f0
 	pop bc
 	ld a, b
 	ld [wNewTileBlockID], a
-	ld bc, $603
+	lb bc, 6, 3
 
 LanceScript_5a2f0: ; 5a2f0 (16:62f0)
 	predef_jump ReplaceTileBlock
--- a/scripts/lavenderhouse1.asm
+++ b/scripts/lavenderhouse1.asm
@@ -72,7 +72,7 @@
 	jr nz, .asm_15ac2
 	ld hl, LavenderHouse1Text_1d94c
 	call PrintText
-	ld bc, (POKE_FLUTE << 8) | 1
+	lb bc, POKE_FLUTE, 1
 	call GiveItem
 	jr nc, .BagFull
 	ld hl, ReceivedFluteText
--- a/scripts/lorelei.asm
+++ b/scripts/lorelei.asm
@@ -23,7 +23,7 @@
 	ld a, $24
 .asm_761ab
 	ld [wNewTileBlockID], a
-	ld bc, $2
+	lb bc, 0, 2
 	predef_jump ReplaceTileBlock
 
 LoreleiScript_761b6: ; 761b6 (1d:61b6)
--- a/scripts/mansion1.asm
+++ b/scripts/mansion1.asm
@@ -15,22 +15,22 @@
 	ret z
 	CheckEvent EVENT_MANSION_SWITCH_ON
 	jr nz, .asm_442ec
-	ld bc, $060c
+	lb bc, 6, 12
 	call Mansion1Script_4430b
-	ld bc, $0308
+	lb bc, 3, 8
 	call Mansion1Script_44304
-	ld bc, $080a
+	lb bc, 8, 10
 	call Mansion1Script_44304
-	ld bc, $0d0d
+	lb bc, 13, 13
 	jp Mansion1Script_44304
 .asm_442ec
-	ld bc, $060c
+	lb bc, 6, 12
 	call Mansion1Script_44304
-	ld bc, $0308
+	lb bc, 3, 8
 	call Mansion1Script_4430b
-	ld bc, $080a
+	lb bc, 8, 10
 	call Mansion1Script_4430b
-	ld bc, $0d0d
+	lb bc, 13, 13
 	jp Mansion1Script_4430b
 
 Mansion1Script_44304: ; 44304 (11:4304)
--- a/scripts/mansion2.asm
+++ b/scripts/mansion2.asm
@@ -16,24 +16,24 @@
 	CheckEvent EVENT_MANSION_SWITCH_ON
 	jr nz, .asm_52016
 	ld a, $e
-	ld bc, $204
+	lb bc, 2, 4
 	call Mansion2Script_5202f
 	ld a, $54
-	ld bc, $409
+	lb bc, 4, 9
 	call Mansion2Script_5202f
 	ld a, $5f
-	ld bc, $b03
+	lb bc, 11, 3
 	call Mansion2Script_5202f
 	ret
 .asm_52016
 	ld a, $5f
-	ld bc, $204
+	lb bc, 2, 4
 	call Mansion2Script_5202f
 	ld a, $e
-	ld bc, $409
+	lb bc, 4, 9
 	call Mansion2Script_5202f
 	ld a, $e
-	ld bc, $b03
+	lb bc, 11, 3
 	call Mansion2Script_5202f
 	ret
 
--- a/scripts/mtmoon3.asm
+++ b/scripts/mtmoon3.asm
@@ -271,7 +271,7 @@
 	ld a, [wCurrentMenuItem]
 	and a
 	jr nz, .asm_49f21
-	ld bc,(DOME_FOSSIL << 8) | 1
+	lb bc, DOME_FOSSIL, 1
 	call GiveItem
 	jp nc, MtMoon3Script_49f76
 	call MtMoon3Script_49f69
@@ -299,7 +299,7 @@
 	ld a, [wCurrentMenuItem]
 	and a
 	jr nz, .asm_49f61
-	ld bc, (HELIX_FOSSIL << 8) | 1
+	lb bc, HELIX_FOSSIL, 1
 	call GiveItem
 	jp nc, MtMoon3Script_49f76
 	call MtMoon3Script_49f69
--- a/scripts/mtmoonpokecenter.asm
+++ b/scripts/mtmoonpokecenter.asm
@@ -43,7 +43,7 @@
 	ld hl, MtMoonPokecenterText_49366
 	jr .printText
 .enoughMoney
-	ld bc,(MAGIKARP << 8) | 5
+	lb bc, MAGIKARP, 5
 	call GivePokemon
 	jr nc, .done
 	xor a
--- a/scripts/museum1f.asm
+++ b/scripts/museum1f.asm
@@ -191,7 +191,7 @@
 	jr nz, .asm_5c285
 	ld hl, Museum1FText_5c28e
 	call PrintText
-	ld bc, (OLD_AMBER << 8) | 1
+	lb bc, OLD_AMBER, 1
 	call GiveItem
 	jr nc, .BagFull
 	SetEvent EVENT_GOT_OLD_AMBER
--- a/scripts/oakslab.asm
+++ b/scripts/oakslab.asm
@@ -1022,7 +1022,7 @@
 .asm_1d2d0
 	CheckAndSetEvent EVENT_GOT_POKEBALLS_FROM_OAK
 	jr nz, .asm_1d2e7
-	ld bc, (POKE_BALL << 8) | 5
+	lb bc, POKE_BALL, 5
 	call GiveItem
 	ld hl, OaksLabGivePokeballsText
 	call PrintText
--- a/scripts/pewtergym.asm
+++ b/scripts/pewtergym.asm
@@ -47,7 +47,7 @@
 	ld [hSpriteIndexOrTextID], a
 	call DisplayTextID
 	SetEvent EVENT_BEAT_BROCK
-	ld bc, (TM_34 << 8) | 1
+	lb bc, TM_34, 1
 	call GiveItem
 	jr nc, .BagFull
 	ld a, $5
--- a/scripts/rockethideout1.asm
+++ b/scripts/rockethideout1.asm
@@ -27,7 +27,7 @@
 	ld a, $e
 .asm_44c03
 	ld [wNewTileBlockID], a
-	ld bc, $080c
+	lb bc, 8, 12
 	predef_jump ReplaceTileBlock
 
 RocketHideout1ScriptPointers: ; 44c0e (11:4c0e)
--- a/scripts/rockethideout4.asm
+++ b/scripts/rockethideout4.asm
@@ -27,7 +27,7 @@
 	ld a, $e
 .asm_45498
 	ld [wNewTileBlockID], a
-	ld bc, $050c
+	lb bc, 5, 12
 	predef_jump ReplaceTileBlock
 
 RocketHideout4Script_454a3: ; 454a3 (11:54a3)
--- a/scripts/route1.asm
+++ b/scripts/route1.asm
@@ -12,7 +12,7 @@
 	jr nz, .asm_1cada
 	ld hl, Route1ViridianMartSampleText
 	call PrintText
-	ld bc, (POTION << 8) | 1
+	lb bc, POTION, 1
 	call GiveItem
 	jr nc, .BagFull
 	ld hl, Route1Text_1cae8
--- a/scripts/route12gateupstairs.asm
+++ b/scripts/route12gateupstairs.asm
@@ -12,7 +12,7 @@
 	jr c, .asm_0ad3c
 	ld hl, TM39PreReceiveText
 	call PrintText
-	ld bc, (TM_39 << 8) | 1
+	lb bc, TM_39, 1
 	call GiveItem
 	jr nc, .BagFull
 	ld hl, ReceivedTM39Text
--- a/scripts/route12house.asm
+++ b/scripts/route12house.asm
@@ -15,7 +15,7 @@
 	ld a, [wCurrentMenuItem]
 	and a
 	jr nz, .asm_a2d76
-	ld bc, (SUPER_ROD << 8) | 1
+	lb bc, SUPER_ROD, 1
 	call GiveItem
 	jr nc, .BagFull
 	ld hl, wd728
--- a/scripts/route16house.asm
+++ b/scripts/route16house.asm
@@ -12,7 +12,7 @@
 	jr nz, .asm_13616
 	ld hl, Route16HouseText3
 	call PrintText
-	ld bc, (HM_02 << 8) | 1
+	lb bc, HM_02, 1
 	call GiveItem
 	jr nc, .BagFull
 	SetEvent EVENT_GOT_HM02
--- a/scripts/route24.asm
+++ b/scripts/route24.asm
@@ -149,7 +149,7 @@
 	jr nz, .asm_514f9
 	ld hl, Route24Text_51510
 	call PrintText
-	ld bc, (NUGGET << 8) | 1
+	lb bc, NUGGET, 1
 	call GiveItem
 	jr nc, .BagFull
 	SetEvent EVENT_GOT_NUGGET
--- a/scripts/safarizoneentrance-yellow.asm
+++ b/scripts/safarizoneentrance-yellow.asm
@@ -54,7 +54,7 @@
 	ld hl,.MakePaymentText
 	call PrintText
 	ld a,30
-	ld hl,(502 / $100) << 8 | (502 % $100)
+	lb hl, (502 / $100),  (502 % $100)
 .xf1ff2
 	ld [W_NUMSAFARIBALLS],a
 	ld a,h
--- a/scripts/safarizonesecrethouse.asm
+++ b/scripts/safarizonesecrethouse.asm
@@ -10,7 +10,7 @@
 	jr nz, .asm_20a9b
 	ld hl, SafariZoneSecretHouseText_4a350
 	call PrintText
-	ld bc, (HM_03 << 8) | 1
+	lb bc, HM_03, 1
 	call GiveItem
 	jr nc, .BagFull
 	ld hl, ReceivedHM03Text
--- a/scripts/saffrongym.asm
+++ b/scripts/saffrongym.asm
@@ -47,7 +47,7 @@
 	ld [hSpriteIndexOrTextID], a
 	call DisplayTextID
 	SetEvent EVENT_BEAT_SABRINA
-	ld bc, (TM_46 << 8) | 1
+	lb bc, TM_46, 1
 	call GiveItem
 	jr nc, .BagFull
 	ld a, $b
--- a/scripts/saffronhouse2.asm
+++ b/scripts/saffronhouse2.asm
@@ -10,7 +10,7 @@
 	jr nz, .asm_9e72b
 	ld hl, TM29PreReceiveText
 	call PrintText
-	ld bc,(TM_29 << 8) | 1
+	lb bc, TM_29, 1
 	call GiveItem
 	jr nc, .BagFull
 	ld hl, ReceivedTM29Text
--- a/scripts/silphco10.asm
+++ b/scripts/silphco10.asm
@@ -13,7 +13,7 @@
 	bit 5, [hl]
 	res 5, [hl]
 	ret z
-	ld hl, DataTable_5a173
+	ld hl, SilphCo10GateCoords
 	call SilphCo2Script_59d43
 	call SilphCo10Text_5a176
 	CheckEvent EVENT_SILPH_CO_10_UNLOCKED_DOOR
@@ -20,11 +20,12 @@
 	ret nz
 	ld a, $54
 	ld [wNewTileBlockID], a
-	ld bc, $405
+	lb bc, 4, 5
 	predef_jump ReplaceTileBlock
 
-DataTable_5a173: ; 5a173 (16:6173)
-	db $04,$05,$FF
+SilphCo10GateCoords: ; 5a173 (16:6173)
+	db $04,$05
+	db $FF
 
 SilphCo10Text_5a176: ; 5a176 (16:6176)
 	ld a, [$ffe0]
--- a/scripts/silphco11.asm
+++ b/scripts/silphco11.asm
@@ -13,7 +13,7 @@
 	bit 5, [hl]
 	res 5, [hl]
 	ret z
-	ld hl, DataTable_62134
+	ld hl, SilphCo11GateCoords
 	call SilphCo11Script_62137
 	call SilphCo11Script_62163
 	CheckEvent EVENT_SILPH_CO_11_UNLOCKED_DOOR
@@ -20,11 +20,12 @@
 	ret nz
 	ld a, $20
 	ld [wNewTileBlockID], a
-	ld bc, $603
+	lb bc, 6, 3
 	predef_jump ReplaceTileBlock
 
-DataTable_62134: ; 62134 (18:6134)
-	db $06,$03,$FF
+SilphCo11GateCoords: ; 62134 (18:6134)
+	db $06,$03
+	db $FF
 
 SilphCo11Script_62137: ; 62137 (18:6137)
 	push hl
@@ -306,7 +307,7 @@
 	jp nz, .asm_62308
 	ld hl, SilphCoPresidentText
 	call PrintText
-	ld bc, (MASTER_BALL << 8) | 1
+	lb bc, MASTER_BALL, 1
 	call GiveItem
 	jr nc, .BagFull
 	ld hl, ReceivedSilphCoMasterBallText
--- a/scripts/silphco2.asm
+++ b/scripts/silphco2.asm
@@ -13,7 +13,7 @@
 	bit 5, [hl]
 	res 5, [hl]
 	ret z
-	ld hl, DataTable_59d3e
+	ld hl, SilphCo2GateCoords
 	call SilphCo2Script_59d43
 	call SilphCo2Script_59d6f
 	CheckEvent EVENT_SILPH_CO_2_UNLOCKED_DOOR1
@@ -21,7 +21,7 @@
 	push af
 	ld a, $54
 	ld [wNewTileBlockID], a
-	ld bc, $0202
+	lb bc, 2, 2
 	predef ReplaceTileBlock
 	pop af
 .asm_59d2e
@@ -29,11 +29,13 @@
 	ret nz
 	ld a, $54
 	ld [wNewTileBlockID], a
-	ld bc, $0502
+	lb bc, 5, 2
 	predef_jump ReplaceTileBlock
 
-DataTable_59d3e: ; 59d3e (16:5d3e)
-	db $02,$02,$05,$02,$FF
+SilphCo2GateCoords: ; 59d3e (16:5d3e)
+	db $02,$02
+	db $05,$02
+	db $FF
 
 SilphCo2Script_59d43: ; 59d43 (16:5d43)
 	push hl
@@ -141,7 +143,7 @@
 	jr nz, .asm_59de4
 	ld hl, SilphCo2Text_59ded
 	call PrintText
-	ld bc, (TM_36 << 8) | 1
+	lb bc, TM_36, 1
 	call GiveItem
 	ld hl, TM36NoRoomText
 	jr nc, .asm_59de7
--- a/scripts/silphco3.asm
+++ b/scripts/silphco3.asm
@@ -13,7 +13,7 @@
 	bit 5, [hl]
 	res 5, [hl]
 	ret z
-	ld hl, DataTable_59fa8
+	ld hl, SilphCo3GateCoords
 	call SilphCo2Script_59d43
 	call SilphCo3Script_59fad
 	CheckEvent EVENT_SILPH_CO_3_UNLOCKED_DOOR1
@@ -21,7 +21,7 @@
 	push af
 	ld a, $5f
 	ld [wNewTileBlockID], a
-	ld bc, $404
+	lb bc, 4, 4
 	predef ReplaceTileBlock
 	pop af
 .asm_59f98
@@ -29,11 +29,13 @@
 	ret nz
 	ld a, $5f
 	ld [wNewTileBlockID], a
-	ld bc, $408
+	lb bc, 4, 8
 	predef_jump ReplaceTileBlock
 
-DataTable_59fa8: ; 59fa8 (16:5fa8)
-	db $04,$04,$04,$08,$FF
+SilphCo3GateCoords: ; 59fa8 (16:5fa8)
+	db $04,$04
+	db $04,$08
+	db $FF
 
 SilphCo3Script_59fad: ; 59fad (16:5fad)
 	EventFlagAddress hl, EVENT_SILPH_CO_3_UNLOCKED_DOOR1
--- a/scripts/silphco4.asm
+++ b/scripts/silphco4.asm
@@ -13,7 +13,7 @@
 	bit 5, [hl]
 	res 5, [hl]
 	ret z
-	ld hl, SilphCo4Data19d58
+	ld hl, SilphCo4GateCoords
 	call SilphCo4Script_19d5d
 	call SilphCo4Script_19d89
 	CheckEvent EVENT_SILPH_CO_4_UNLOCKED_DOOR1
@@ -21,7 +21,7 @@
 	push af
 	ld a, $54
 	ld [wNewTileBlockID], a
-	ld bc, $0602
+	lb bc, 6, 2
 	predef ReplaceTileBlock
 	pop af
 .asm_19d48
@@ -29,11 +29,13 @@
 	ret nz
 	ld a, $54
 	ld [wNewTileBlockID], a
-	ld bc, $0406
+	lb bc, 4, 6
 	predef_jump ReplaceTileBlock
 
-SilphCo4Data19d58: ; 19d58 (6:5d58)
-	db $06, $02, $04, $06, $ff
+SilphCo4GateCoords: ; 19d58 (6:5d58)
+	db $06,$02
+	db $04,$06
+	db $FF
 
 SilphCo4Script_19d5d: ; 19d5d (6:5d5d)
 	push hl
--- a/scripts/silphco5.asm
+++ b/scripts/silphco5.asm
@@ -13,7 +13,7 @@
 	bit 5, [hl]
 	res 5, [hl]
 	ret z
-	ld hl, SilphCo5Coords
+	ld hl, SilphCo5GateCoords
 	call SilphCo4Script_19d5d
 	call SilphCo5Script_19f9e
 	CheckEvent EVENT_SILPH_CO_5_UNLOCKED_DOOR1
@@ -21,7 +21,7 @@
 	push af
 	ld a, $5f
 	ld [wNewTileBlockID], a
-	ld bc, $0203
+	lb bc, 2, 3
 	predef ReplaceTileBlock
 	pop af
 .asm_19f74
@@ -30,7 +30,7 @@
 	push af
 	ld a, $5f
 	ld [wNewTileBlockID], a
-	ld bc, $0603
+	lb bc, 6, 3
 	predef ReplaceTileBlock
 	pop af
 .asm_19f87
@@ -38,11 +38,14 @@
 	ret nz
 	ld a, $5f
 	ld [wNewTileBlockID], a
-	ld bc, $0507
+	lb bc, 5, 7
 	predef_jump ReplaceTileBlock
 
-SilphCo5Coords: ; 19f97 (6:5f97)
-	db $02, $03, $06, $03, $05, $07, $ff
+SilphCo5GateCoords: ; 19f97 (6:5f97)
+	db $02,$03
+	db $06,$03
+	db $05,$07
+	db $FF
 
 SilphCo5Script_19f9e: ; 19f9e (6:5f9e)
 	EventFlagAddress hl, EVENT_SILPH_CO_5_UNLOCKED_DOOR1
--- a/scripts/silphco6.asm
+++ b/scripts/silphco6.asm
@@ -13,7 +13,7 @@
 	bit 5, [hl]
 	res 5, [hl]
 	ret z
-	ld hl, SilphCo6Coords1
+	ld hl, SilphCo6GateCoords
 	call SilphCo4Script_19d5d
 	call SilphCo6Script_1a1e6
 	CheckEvent EVENT_SILPH_CO_6_UNLOCKED_DOOR
@@ -20,12 +20,12 @@
 	ret nz
 	ld a, $5f
 	ld [wNewTileBlockID], a
-	ld bc, $0602
+	lb bc, 6, 2
 	predef_jump ReplaceTileBlock
 
-SilphCo6Coords1: ; 1a1e3 (6:61e3)
-	db $06, $02
-	db $ff
+SilphCo6GateCoords: ; 1a1e3 (6:61e3)
+	db $06,$02
+	db $FF
 
 SilphCo6Script_1a1e6: ; 1a1e6 (6:61e6)
 	ld a, [$ffe0]
--- a/scripts/silphco7.asm
+++ b/scripts/silphco7.asm
@@ -13,7 +13,7 @@
 	bit 5, [hl]
 	res 5, [hl]
 	ret z
-	ld hl, DataTable_51bc1
+	ld hl, SilphCo7GateCoords
 	call SilphCo7Text_51bc8
 	call SilphCo7Text_51bf4
 	CheckEvent EVENT_SILPH_CO_7_UNLOCKED_DOOR1
@@ -21,7 +21,7 @@
 	push af
 	ld a, $54
 	ld [wNewTileBlockID], a
-	ld bc, $305
+	lb bc, 3, 5
 	predef ReplaceTileBlock
 	pop af
 .asm_51b9e
@@ -30,7 +30,7 @@
 	push af
 	ld a, $54
 	ld [wNewTileBlockID], a
-	ld bc, $20a
+	lb bc, 2, 10
 	predef ReplaceTileBlock
 	pop af
 .asm_51bb1
@@ -38,11 +38,14 @@
 	ret nz
 	ld a, $54
 	ld [wNewTileBlockID], a
-	ld bc, $60a
+	lb bc, 6, 10
 	predef_jump ReplaceTileBlock
 
-DataTable_51bc1: ; 51bc1 (14:5bc1)
-	db $03,$05,$02,$0A,$06,$0A,$FF
+SilphCo7GateCoords: ; 51bc1 (14:5bc1)
+	db $03,$05
+	db $02,$0A
+	db $06,$0A
+	db $FF
 
 SilphCo7Text_51bc8: ; 51bc8 (14:5bc8)
 	push hl
@@ -329,7 +332,7 @@
 .givelapras
 	ld hl, .MeetLaprasGuyText
 	call PrintText
-	ld bc, (LAPRAS << 8) | 15
+	lb bc, LAPRAS, 15
 	call GivePokemon
 	jr nc, .done
 	ld a, [wSimulatedJoypadStatesEnd]
--- a/scripts/silphco8.asm
+++ b/scripts/silphco8.asm
@@ -13,7 +13,7 @@
 	bit 5, [hl]
 	res 5, [hl]
 	ret z
-	ld hl, DataTable_5653e
+	ld hl, SilphCo8GateCoords
 	call SilphCo8Script_56541
 	call SilphCo8Script_5656d
 	CheckEvent EVENT_SILPH_CO_8_UNLOCKED_DOOR
@@ -20,11 +20,12 @@
 	ret nz
 	ld a, $5f
 	ld [wNewTileBlockID], a
-	ld bc, $403
+	lb bc, 4, 3
 	predef_jump ReplaceTileBlock
 
-DataTable_5653e: ; 5653e (15:653e)
-	db $04,$03,$FF
+SilphCo8GateCoords: ; 5653e (15:653e)
+	db $04,$03
+	db $FF
 
 SilphCo8Script_56541: ; 56541 (15:6541)
 	push hl
--- a/scripts/silphco9.asm
+++ b/scripts/silphco9.asm
@@ -13,7 +13,7 @@
 	bit 5, [hl]
 	res 5, [hl]
 	ret z
-	ld hl, DataTable_5d82e
+	ld hl, SilphCo9GateCoords
 	call SilphCo9Script_5d837
 	call SilphCo9Script_5d863
 	CheckEvent EVENT_SILPH_CO_9_UNLOCKED_DOOR1
@@ -21,7 +21,7 @@
 	push af
 	ld a, $5f
 	ld [wNewTileBlockID], a
-	ld bc, $401
+	lb bc, 4, 1
 	predef ReplaceTileBlock
 	pop af
 .asm_5d7f8
@@ -30,7 +30,7 @@
 	push af
 	ld a, $54
 	ld [wNewTileBlockID], a
-	ld bc, $209
+	lb bc, 2, 9
 	predef ReplaceTileBlock
 	pop af
 .asm_5d80b
@@ -39,7 +39,7 @@
 	push af
 	ld a, $54
 	ld [wNewTileBlockID], a
-	ld bc, $509
+	lb bc, 5, 9
 	predef ReplaceTileBlock
 	pop af
 .asm_5d81e
@@ -47,11 +47,15 @@
 	ret nz
 	ld a, $5f
 	ld [wNewTileBlockID], a
-	ld bc, $605
+	lb bc, 6, 5
 	predef_jump ReplaceTileBlock
 
-DataTable_5d82e: ; 5d82e (17:582e)
-	db $04,$01,$02,$09,$05,$09,$06,$05,$FF
+SilphCo9GateCoords: ; 5d82e (17:582e)
+	db $04,$01
+	db $02,$09
+	db $05,$09
+	db $06,$05
+	db $FF
 
 SilphCo9Script_5d837: ; 5d837 (17:5837)
 	push hl
--- a/scripts/ssanne7.asm
+++ b/scripts/ssanne7.asm
@@ -22,7 +22,7 @@
 	call PrintText
 	ld hl, ReceivingHM01Text
 	call PrintText
-	ld bc, (HM_01 << 8) | 1
+	lb bc, HM_01, 1
 	call GiveItem
 	jr nc, .BagFull
 	ld hl, ReceivedHM01Text
--- a/scripts/vermiliongym.asm
+++ b/scripts/vermiliongym.asm
@@ -38,7 +38,7 @@
 	ld a, $5
 .asm_5ca7f
 	ld [wNewTileBlockID], a
-	ld bc, $202
+	lb bc, 2, 2
 	predef_jump ReplaceTileBlock
 
 VermilionGymScript_5ca8a: ; 5ca8a (17:4a8a)
@@ -66,7 +66,7 @@
 	ld [hSpriteIndexOrTextID], a
 	call DisplayTextID
 	SetEvent EVENT_BEAT_LT_SURGE
-	ld bc, (TM_24 << 8) | 1
+	lb bc, TM_24, 1
 	call GiveItem
 	jr nc, .BagFull
 	ld a, $7
--- a/scripts/vermilionhouse2.asm
+++ b/scripts/vermilionhouse2.asm
@@ -15,7 +15,7 @@
 	ld a, [wCurrentMenuItem]
 	and a
 	jr nz, .asm_eb1b7
-	ld bc, (OLD_ROD << 8) | 1
+	lb bc, OLD_ROD, 1
 	call GiveItem
 	jr nc, .BagFull
 	ld hl, wd728
--- a/scripts/victoryroad1.asm
+++ b/scripts/victoryroad1.asm
@@ -15,7 +15,7 @@
 	ret z
 	ld a, $1d
 	ld [wNewTileBlockID], a
-	ld bc, $604
+	lb bc, 6, 4
 	predef_jump ReplaceTileBlock
 
 VictoryRoad1ScriptPointers: ; 5da3a (17:5a3a)
--- a/scripts/victoryroad2.asm
+++ b/scripts/victoryroad2.asm
@@ -23,7 +23,7 @@
 	jr z, .asm_517da
 	push af
 	ld a, $15
-	ld bc, $403
+	lb bc, 4, 3
 	call VictoryRoad2Script_517e2
 	pop af
 .asm_517da
@@ -30,7 +30,7 @@
 	bit 7, a
 	ret z
 	ld a, $1d
-	ld bc, $70b
+	lb bc, 7, 11
 
 VictoryRoad2Script_517e2: ; 517e2 (14:57e2)
 	ld [wNewTileBlockID], a
--- a/scripts/victoryroad3.asm
+++ b/scripts/victoryroad3.asm
@@ -17,7 +17,7 @@
 	ret z
 	ld a, $1d
 	ld [wNewTileBlockID], a
-	ld bc, $503
+	lb bc, 5, 3
 	predef_jump ReplaceTileBlock
 
 VictoryRoad3ScriptPointers: ; 449b1 (11:49b1)
--- a/scripts/viridiancity.asm
+++ b/scripts/viridiancity.asm
@@ -235,7 +235,7 @@
 	jr nz, .asm_4e5a0
 	ld hl, ViridianCityText_191ca
 	call PrintText
-	ld bc, (TM_42 << 8) | 1
+	lb bc, TM_42, 1
 	call GiveItem
 	jr nc, .BagFull
 	ld hl, ReceivedTM42Text
--- a/scripts/viridiangym.asm
+++ b/scripts/viridiangym.asm
@@ -141,7 +141,7 @@
 	ld [hSpriteIndexOrTextID], a
 	call DisplayTextID
 	SetEvent EVENT_BEAT_VIRIDIAN_GYM_GIOVANNI
-	ld bc, (TM_27 << 8) | 1
+	lb bc, TM_27, 1
 	call GiveItem
 	jr nc, .BagFull
 	ld a, $d
--- a/scripts/viridianmart.asm
+++ b/scripts/viridianmart.asm
@@ -52,7 +52,7 @@
 	ld a, $5
 	ld [hSpriteIndexOrTextID], a
 	call DisplayTextID
-	ld bc, (OAKS_PARCEL << 8) + 1
+	lb bc, OAKS_PARCEL, 1
 	call GiveItem
 	SetEvent EVENT_GOT_OAKS_PARCEL
 	ld a, $2
--- a/home.asm
+++ b/home.asm
@@ -1402,7 +1402,7 @@
 	call UpdateSprites ; disable sprites behind the text box
 ; the code up to .skipMovingSprites appears to be useless
 	coord hl, 4, 2 ; coordinates of upper left corner of menu text box
-	ld de,$090e ; height and width of menu text box
+	lb de, 9, 14 ; height and width of menu text box
 	ld a,[wListMenuID]
 	and a ; is it a PC pokemon list?
 	jr nz,.skipMovingSprites
@@ -1668,7 +1668,7 @@
 	coord hl, 9, 10
 .printQuantity
 	ld de,wItemQuantity ; current quantity
-	lb bc,LEADING_ZEROES | 1, 2 ; 1 byte, 2 digits
+	lb bc, LEADING_ZEROES | 1, 2 ; 1 byte, 2 digits
 	call PrintNumber
 	jp .waitForKeyPressLoop
 .buttonAPressed ; the player chose to make the transaction
@@ -1705,8 +1705,8 @@
 
 PrintListMenuEntries:: ; 2e5a (0:2e5a)
 	coord hl, 5, 3
-	ld b,$09
-	ld c,$0e
+	ld b,9
+	ld c,14
 	call ClearScreenArea
 	ld a,[wListPointer]
 	ld e,a
@@ -1786,7 +1786,7 @@
 	ld [wcf91],a
 	call GetItemPrice ; get price
 	pop hl
-	ld bc,20 + 5 ; 1 row down and 5 columns right
+	ld bc, SCREEN_WIDTH + 5 ; 1 row down and 5 columns right
 	add hl,bc
 	ld c,$a3 ; no leading zeroes, right-aligned, print currency symbol, 3 bytes
 	call PrintBCDNumber
@@ -1815,7 +1815,7 @@
 	ld a,[wListScrollOffset]
 	add b
 	ld [hl],a
-	call LoadMonData ; load pokemon info
+	call LoadMonData
 	ld a,[wMonDataLocation]
 	and a ; is it a list of party pokemon or box pokemon?
 	jr z,.skipCopyingLevel
@@ -1826,7 +1826,7 @@
 	pop hl
 	ld bc,$001c
 	add hl,bc
-	call PrintLevel ; print level
+	call PrintLevel
 	pop af
 	ld [wd11e],a
 .skipPrintingPokemonLevel
@@ -1844,7 +1844,7 @@
 	and a ; is the item unsellable?
 	jr nz,.skipPrintingItemQuantity ; if so, don't print the quantity
 	push hl
-	ld bc,20 + 8 ; 1 row down and 8 columns right
+	ld bc, SCREEN_WIDTH + 8 ; 1 row down and 8 columns right
 	add hl,bc
 	ld a,"×"
 	ld [hli],a
@@ -1877,7 +1877,7 @@
 	ld a,$ec ; unfilled right arrow menu cursor to indicate an item being swapped
 	ld [hli],a
 .nextListEntry
-	ld bc,2 * 20 ; 2 rows
+	ld bc,2 * SCREEN_WIDTH ; 2 rows
 	add hl,bc
 	pop bc
 	inc c
@@ -1899,12 +1899,12 @@
 	push hl
 	ld a,[H_LOADEDROMBANK]
 	push af
-	ld a,BANK(MonsterNames) ; 07
+	ld a,BANK(MonsterNames)
 	ld [H_LOADEDROMBANK],a
 	ld [MBC1RomBank],a
 	ld a,[wd11e]
 	dec a
-	ld hl,MonsterNames ; 421E
+	ld hl,MonsterNames
 	ld c,10
 	ld b,0
 	call AddNTimes
@@ -1972,7 +1972,7 @@
 ; now get the machine number and convert it to text
 	ld a,[wd11e]
 	sub TM_01 - 1
-	ld b,$F6 ; "0"
+	ld b, "0"
 .FirstDigit
 	sub 10
 	jr c,.SecondDigit
@@ -1985,7 +1985,7 @@
 	ld [de],a
 	inc de
 	pop af
-	ld b,$F6 ; "0"
+	ld b, "0"
 	add b
 	ld [de],a
 	inc de
@@ -2134,6 +2134,7 @@
 ; function to draw various text boxes
 ; INPUT:
 ; [wTextBoxID] = text box ID
+; b, c = y, x cursor position (TWO_OPTION_MENU only)
 DisplayTextBoxID:: ; 30e8 (0:30e8)
 	ld a,[H_LOADEDROMBANK]
 	push af
@@ -3002,7 +3003,7 @@
 	ld a, HEAL_CANCEL_MENU
 	ld [wTwoOptionMenuID], a
 	coord hl, 11, 6
-	ld bc, $80c
+	lb bc, 8, 12
 	jr DisplayYesNoChoice
 
 Func_361a:: ; 361a (0:361a)
@@ -3010,7 +3011,7 @@
 	ld a, WIDE_YES_NO_MENU
 	ld [wTwoOptionMenuID], a
 	coord hl, 12, 7
-	ld bc, $080d
+	lb bc, 8, 13
 DisplayYesNoChoice:: ; 3628 (0:3628)
 	ld a, TWO_OPTION_MENU
 	ld [wTextBoxID], a
@@ -3097,7 +3098,7 @@
 .on
 	ld de, FontGraphics
 	ld hl, vFont
-	ld bc, BANK(FontGraphics) << 8 | $80
+	lb bc, BANK(FontGraphics), $80
 	jp CopyVideoDataDouble ; if LCD is on, transfer during V-blank
 
 LoadTextBoxTilePatterns::
@@ -3113,7 +3114,7 @@
 .on
 	ld de, TextBoxGraphics
 	ld hl, vChars2 + $600
-	ld bc, BANK(TextBoxGraphics) << 8 | $20
+	lb bc, BANK(TextBoxGraphics), $20
 	jp CopyVideoData ; if LCD is on, transfer during V-blank
 
 LoadHpBarAndStatusTilePatterns::
@@ -3129,7 +3130,7 @@
 .on
 	ld de, HpBarAndStatusGraphics
 	ld hl, vChars2 + $620
-	ld bc, BANK(HpBarAndStatusGraphics) << 8 | $1e
+	lb bc, BANK(HpBarAndStatusGraphics), $1e
 	jp CopyVideoData ; if LCD is on, transfer during V-blank
 
 
@@ -3824,12 +3825,12 @@
 	ld [MBC1RomBank], a
 	ret
 
 ; skips a text entries, each of size $b (like trainer name, OT name, rival name, ...)
 ; hl: base pointer, will be incremented by $b * a
 SkipFixedLengthTextEntries:: ; 3a7d (0:3a7d)
 	and a
 	ret z
-	ld bc, $b
+	ld bc, 11
 .skipLoop
 	add hl, bc
 	dec a
@@ -3824,12 +3825,12 @@
 	ret
 
-; skips a text entries, each of size $b (like trainer name, OT name, rival name, ...)
+; skips a text entries, each of size 11 (like trainer name, OT name, rival name, ...)
 ; hl: base pointer, will be incremented by $b * a
 SkipFixedLengthTextEntries:: ; 3a7d (0:3a7d)